@@ -516,8 +516,14 @@ int main(int argc, const char **argv){
 						DVwait = FALSE;
 						if (!dat) dat = fopen ("/tmp/dv_echo.bin", "wb");
 						if (send_packet.B_header.seq == 0x80)
+						{
 							memcpy (&CallerCall, &send_packet.header.MyCall, 8);
-						fwrite ((char *)&send_packet, 56, 1, dat);
+							fwrite ((char *)&send_packet, 56, 1, dat);
+							audio_msg(CallerCall, client_call);
+						}
+						else 
+                                                        fwrite ((char *)&send_packet, 56, 1, dat);
+
 						if (send_packet.B_header.seq & 0x40)
 						{
 							fclose (dat);
